import { Options } from './options.js';
import { ProviderType } from './provider-type.js';
import { WebHook } from './providers/webhook.js';
import { TwilioSMS } from './providers/twilio-sms.js';
import { TwilioSendgrid } from './providers/twilio-sendgrid.js';
import { AWSSES } from './providers/aws-ses.js';
import { AWSSMS } from './providers/aws-sms.js';
import { FirebaseMessaging } from './providers/firebase-messaging.js';
import { AWSSNS } from './providers/aws-sns.js';
export class ProviderService {
    constructor(options) {
        this.options = new Options();
        this._providers = new Array();
        if (options) {
            this.options = new Options(options);
        }
        this.loadProviders();
    }
    get providers() {
        return this._providers;
    }
    get sms() {
        return this.getProviderByType(ProviderType.SMS);
    }
    get smtp() {
        return this.getProviderByType(ProviderType.SMTP);
    }
    get webhook() {
        return this.getProviderByType(ProviderType.WEBHOOK);
    }
    get mobilePush() {
        return this.getProviderByType(ProviderType.MOBILE_PUSH);
    }
    getProviderByType(type) {
        let result = [];
        const provider = this._providers.filter(provider => provider.type === type);
        if (provider.length > 0) {
            result = provider;
        }
        return result;
    }
    removeProvider(name) {
        const index = this._providers.findIndex(provider => provider.name === name);
        if (index > -1) {
            this._providers.splice(index, 1);
        }
    }
    addProvider(provider) {
        if (this.providerExists(provider.name)) {
            throw new Error(`Provider ${String(provider.name)} already exists`);
        }
        else {
            this._providers.push(provider);
        }
    }
    providerExists(name) {
        return this.getProvider(name) !== undefined;
    }
    updateProvider(provider) {
        if (this.providerExists(provider.name)) {
            this.removeProvider(provider.name);
        }
        this.addProvider(provider);
    }
    getProvider(name) {
        let result;
        for (const provider of this._providers) {
            if (provider.name === name) {
                result = provider;
                break;
            }
        }
        return result;
    }
    loadProviders() {
        this._providers.push(new WebHook());
        if (this.options.TWILIO_SMS_ACCOUNT_SID.length > 0 && this.options.TWILIO_SMS_AUTH_TOKEN.length > 0) {
            this._providers.push(new TwilioSMS(this.options.TWILIO_SMS_ACCOUNT_SID, this.options.TWILIO_SMS_AUTH_TOKEN));
        }
        if (this.options.TWILIO_SENDGRID_API_KEY.length > 0) {
            this._providers.push(new TwilioSendgrid(this.options.TWILIO_SENDGRID_API_KEY));
        }
        if (this.options.AWS_SES_REGION.length > 0) {
            this._providers.push(new AWSSES(this.options.AWS_SES_REGION));
        }
        if (this.options.AWS_SMS_REGION.length > 0) {
            this._providers.push(new AWSSMS(this.options.AWS_SMS_REGION));
        }
        if (this.options.AWS_SNS_REGION.length > 0) {
            this._providers.push(new AWSSNS(this.options.AWS_SNS_REGION));
        }
        if (this.options.FIREBASE_CERT.length > 0) {
            this._providers.push(new FirebaseMessaging(this.options.FIREBASE_CERT));
        }
    }
}
//# sourceMappingURL=provider-service.js.map