/* eslint-disable @typescript-eslint/no-unsafe-argument */
import { Ecto } from 'ecto';
import fs from 'fs-extra';
import matter from 'gray-matter';
import { Options } from './options.js';
import { TemplateText } from './template-text.js';
export class Template {
    constructor(filePath) {
        this.options = new Options();
        this.text = new Map();
        this.loadTemplate(filePath);
    }
    get name() {
        return this.getFileName(this.filePath);
    }
    getText(serviceType, languageCode) {
        if (languageCode === undefined) {
            languageCode = this.options.DEFAULT_TEMPLATE_LANGUAGE;
        }
        let result = this.text.get(this.generateKey(languageCode, serviceType));
        if (result === undefined) {
            result = new TemplateText();
        }
        return result;
    }
    getProperty(serviceType, propertyName, languageCode) {
        const text = this.getText(serviceType, languageCode);
        const result = text.properties.get(propertyName);
        if (result) {
            return result.toString();
        }
        return '';
    }
    /* eslint max-params: [2, 5] */
    setText(serviceType, languageCode, text, format, properties) {
        this.text.set(this.generateKey(languageCode, serviceType), new TemplateText(text, format, languageCode, properties));
    }
    loadTemplate(filePath) {
        if (filePath !== undefined) {
            this.filePath = filePath;
            if (fs.pathExistsSync(this.filePath)) {
                const dirs = fs.readdirSync(this.filePath);
                for (const d of dirs) {
                    const dFilePath = `${this.filePath}/${d}`;
                    if (fs.statSync(dFilePath).isDirectory()) {
                        const dirLangCode = this.getFileName(dFilePath);
                        this.loadTemplateDirectory(dFilePath, dirLangCode);
                    }
                    else {
                        this.loadTemplateFile(dFilePath);
                    }
                }
            }
        }
    }
    async render(serviceType, data, languageCode) {
        let result = '';
        const ecto = new Ecto();
        if (this.filePath !== undefined) {
            const templateText = this.getText(serviceType, languageCode);
            result = await ecto.render(templateText.text, data, templateText.format);
        }
        return result;
    }
    getFileName(filePath) {
        let result = '';
        if (filePath !== undefined) {
            const name = filePath.split('/').pop();
            if (name !== undefined) {
                result = name.toLowerCase().trim();
            }
        }
        return result;
    }
    generateKey(languageCode, serviceType) {
        languageCode = languageCode.toLowerCase().trim();
        serviceType = serviceType.toLowerCase().trim();
        return `${languageCode}-${serviceType}`;
    }
    loadTemplateDirectory(filePath, languageCode) {
        const files = fs.readdirSync(filePath);
        for (const fp of files) {
            this.loadTemplateFile(filePath + '/' + fp, languageCode);
        }
    }
    loadTemplateFile(filePath, languageCode) {
        if (languageCode === undefined) {
            languageCode = this.options.DEFAULT_TEMPLATE_LANGUAGE;
        }
        const fileText = fs.readFileSync(filePath).toString();
        const fileData = matter(fileText);
        const fileServiceType = this.getFileName(filePath).split('.')[0];
        const ecto = new Ecto();
        const format = ecto.getEngineByFilePath(filePath);
        this.setText(fileServiceType, languageCode, fileData.content, format, fileData.data);
    }
}
//# sourceMappingURL=template.js.map